.. _coder:

I am a **HTML coder** - where do I begin?
#########################################

As the creator of the templates, you should first get confident when working
with `Django templates`_. You should have good understanding of following concepts:

* What are templates and how they are defined.
* How to work with variables.
* How to use use filters and what they are for.
* What are Django templatetags and how to use them.
* Basic overview of the in-built Django templatetags.
* Template inheritance.

It would also be very handy, if you had basic understanding of how Django
itself works, what are **views** and **models**. If you are familiar with all
the mentioned topics, great! You are ready to jump into Ella right now. Here is
a topic walkthrough we think will be ideal for you.

**First**, start with :ref:`tutorial`. It covers the core principles in brief detail
and should get you in touch with Ella basics. You will get familiar with basic
Ella project setup, the most common templates, and the important models
Ella is all about. As a **next step**, go to :ref:`features` section and try
to consume as much as possible from these topics:

* :ref:`features-template-fallback-mechanisms`
* :ref:`features-category-detail`
* :ref:`features-object-detail`
* :ref:`features-positions`
* :ref:`features-photos`
* :ref:`features-related`
* :ref:`features-syndication`

If all those topics make sense, you will probably feel at home when going 
to :ref:`common-gotchas` section, which will hopefully give you last remaining
pieces of the puzzle. If still having questions, please contact us and give us the
very welcomed feedback what is **missing in the docs**!

.. _Django templates: https://docs.djangoproject.com/en/dev/topics/templates/
